package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.BomanReservatConfigTimeMapper;
import com.ruoyi.system.domain.BomanReservatConfigTime;
import com.ruoyi.system.service.IBomanReservatConfigTimeService;

/**
 * 预约时段配置Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-02-27
 */
@Service
public class BomanReservatConfigTimeServiceImpl implements IBomanReservatConfigTimeService 
{
    @Autowired
    private BomanReservatConfigTimeMapper bomanReservatConfigTimeMapper;

    /**
     * 查询预约时段配置
     * 
     * @param reservatConfigTimeId 预约时段配置主键
     * @return 预约时段配置
     */
    @Override
    public BomanReservatConfigTime selectBomanReservatConfigTimeByReservatConfigTimeId(Long reservatConfigTimeId)
    {
        return bomanReservatConfigTimeMapper.selectBomanReservatConfigTimeByReservatConfigTimeId(reservatConfigTimeId);
    }

    /**
     * 查询预约时段配置列表
     * 
     * @param bomanReservatConfigTime 预约时段配置
     * @return 预约时段配置
     */
    @Override
    public List<BomanReservatConfigTime> selectBomanReservatConfigTimeList(BomanReservatConfigTime bomanReservatConfigTime)
    {
        return bomanReservatConfigTimeMapper.selectBomanReservatConfigTimeList(bomanReservatConfigTime);
    }

    /**
     * 新增预约时段配置
     * 
     * @param bomanReservatConfigTime 预约时段配置
     * @return 结果
     */
    @Override
    public int insertBomanReservatConfigTime(BomanReservatConfigTime bomanReservatConfigTime)
    {
        bomanReservatConfigTime.setCreateTime(DateUtils.getNowDate());
        return bomanReservatConfigTimeMapper.insertBomanReservatConfigTime(bomanReservatConfigTime);
    }

    /**
     * 修改预约时段配置
     * 
     * @param bomanReservatConfigTime 预约时段配置
     * @return 结果
     */
    @Override
    public int updateBomanReservatConfigTime(BomanReservatConfigTime bomanReservatConfigTime)
    {
        bomanReservatConfigTime.setUpdateTime(DateUtils.getNowDate());
        return bomanReservatConfigTimeMapper.updateBomanReservatConfigTime(bomanReservatConfigTime);
    }

    /**
     * 批量删除预约时段配置
     * 
     * @param reservatConfigTimeIds 需要删除的预约时段配置主键
     * @return 结果
     */
    @Override
    public int deleteBomanReservatConfigTimeByReservatConfigTimeIds(Long[] reservatConfigTimeIds)
    {
        return bomanReservatConfigTimeMapper.deleteBomanReservatConfigTimeByReservatConfigTimeIds(reservatConfigTimeIds);
    }

    /**
     * 删除预约时段配置信息
     * 
     * @param reservatConfigTimeId 预约时段配置主键
     * @return 结果
     */
    @Override
    public int deleteBomanReservatConfigTimeByReservatConfigTimeId(Long reservatConfigTimeId)
    {
        return bomanReservatConfigTimeMapper.deleteBomanReservatConfigTimeByReservatConfigTimeId(reservatConfigTimeId);
    }
}
